Package: altmeta
Type: Package
Title: Alternative Meta-Analysis Methods
Version: 4.3.1
Date: 2026-04-29
Authors@R: 
  c(person(given = "Lifeng", family = "Lin",
    role = c("aut", "cre"), email = "lifenglin@arizona.edu",
    comment = c(ORCID = "0000-0002-3562-9816")),
    person(given = "Yaqi", family = "Jing", role = c("ctb")),
    person(given = "Kristine J.", family = "Rosenberger", role = c("ctb")),
    person(given = "Linyu", family = "Shi", role = c("ctb")),
    person(given = "Yipeng", family = "Wang", role = c("ctb")),
    person(given = "Xing", family = "Xing", role = c("ctb"),
    comment = c(ORCID = "0000-0001-9394-8957")),
    person(given = "Zhiyuan", family = "Yu", role = c("ctb")),
    person(given = "Haitao", family = "Chu",
    role = c("aut"), email = "chux0051@umn.edu",
    comment = c(ORCID = "0000-0003-0932-598X")))
Maintainer: Lifeng Lin <lifenglin@arizona.edu>
Depends: R (>= 3.5.0)
Imports: rjags (>= 4-6), coda, graphics, grDevices, lme4, Matrix,
        metafor (>= 3.0-2), methods, stats, utils
SystemRequirements: JAGS 4.x.y (http://mcmc-jags.sourceforge.net)
Description: Provides alternative statistical methods for meta-analysis, including:
 - bivariate generalized linear mixed models for synthesizing odds ratios, relative risks,
   and risk differences
   (Chu et al., 2012 <doi:10.1177/0962280210393712>)
 - tests and measures for between-study heterogeneity
   (Lin et al., 2017 <doi:10.1111/biom.12543>;
    Wang et al., 2022 <doi:10.1002/sim.9261>;
    Yu et al., 2025 <doi:10.1186/s12874-025-02719-7>);
 - measures, tests, and visualization tools for publication bias or small-study effects
   (Lin and Chu, 2018 <doi:10.1111/biom.12817>;
    Lin, 2019 <doi:10.1002/jrsm.1340>;
    Lin, 2020 <doi:10.1177/0962280220910172>;
    Shi et al., 2020 <doi:10.1002/jrsm.1415>);
 - meta-analysis of combining standardized mean differences and odds ratios
   (Jing et al., 2023 <doi:10.1080/10543406.2022.2105345>);
 - meta-analysis of diagnostic tests for synthesizing sensitivities, specificities, etc.
   (Reitsma et al., 2005 <doi:10.1016/j.jclinepi.2005.02.022>;
    Chu and Cole, 2006 <doi:10.1016/j.jclinepi.2006.06.011>);
 - meta-analysis methods for synthesizing proportions
   (Lin and Chu, 2020 <doi:10.1097/ede.0000000000001232>);
 - models for multivariate meta-analysis, measures of inconsistency degrees of freedom
   in Bayesian network meta-analysis, and predictive P-score
   (Lin and Chu, 2018 <doi:10.1002/jrsm.1293>;
    Lin, 2020 <doi:10.1080/10543406.2020.1852247>;
    Rosenberger et al., 2021 <doi:10.1186/s12874-021-01397-5>).
License: GPL (>= 2)
NeedsCompilation: no
Packaged: 2026-04-29 23:49:58 UTC; lifen
Author: Lifeng Lin [aut, cre] (ORCID: <https://orcid.org/0000-0002-3562-9816>),
  Yaqi Jing [ctb],
  Kristine J. Rosenberger [ctb],
  Linyu Shi [ctb],
  Yipeng Wang [ctb],
  Xing Xing [ctb] (ORCID: <https://orcid.org/0000-0001-9394-8957>),
  Zhiyuan Yu [ctb],
  Haitao Chu [aut] (ORCID: <https://orcid.org/0000-0003-0932-598X>)
Repository: CRAN
Date/Publication: 2026-04-30 08:30:36 UTC
Built: R 4.6.0; ; 2026-04-30 11:23:45 UTC; unix
