S3method(plot, meta.dt)
S3method(plot, metaoutliers)
S3method(print, meta.dt)
S3method(print, metahet.hybrid)

export(maprop.glmm, maprop.twostep, meta.biv, meta.dt, meta.or.smd, meta.pen, metahet, metahet.hybrid, metaoutliers, metapb, mvma, mvma.bayesian, mvma.hybrid, mvma.hybrid.bayesian, nma.icdf, nma.predrank, pb.bayesian.binary, pb.hybrid.binary, pb.hybrid.generic, ssfunnel)

import("graphics", "rjags", "stats")

importFrom("coda", "gelman.diag")
importFrom("grDevices", "adjustcolor", "dev.off", "png")
importFrom("lme4", "glmer")
importFrom("Matrix", "rankMatrix")
importFrom("metafor", "rma", "rma.mv")
importFrom("methods", "is")
importFrom("utils", "write.table")