\name{print.meta.dt}
\alias{print.meta.dt}
\title{
Print Method for "meta.dt" Objects
}
\description{
Prints information about a meta-analysis of diagnostic tests.
}
\usage{
\method{print}{meta.dt}(x, digits = 3, ...)
}
\arguments{
  \item{x}{
  an object of class \code{"meta.dt"} produced by the function \code{\link{meta.dt}}.
}
  \item{digits}{
  an integer specifying the number of decimal places to which the printed results should be rounded.
}
  \item{\dots}{
  other arguments.
}
}
%%\details{
%%  ~~ If necessary, more details than the description above ~~
%%}
\value{
None.
}
%%\references{
%% ~put references to the literature/web site here ~
%%}
%%\author{
%%  ~~who you are~~
%%}
%%\note{
%%  ~~further notes~~
%%}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
\code{\link{meta.dt}}, \code{\link{plot.meta.dt}}
}
%%\examples{
%%}
\keyword{print}
